#!/bin/bash

usage() {
  cat 1>&2 <<EOF
usage: ${0##*/} [-f] <product_topdir>
EOF
}

while getopts :f OPT; do
  case $OPT in
    f)
      (( force = 1 ))   
      ;;
    *)
      echo "usage: ${0##*/} [+-f} [--] ARGS..."
       exit 2
    esac
done
shift $(( OPTIND - 1 ))
OPTIND=1

product_topdir="${1}"

[[ -d "${product_topdir}" ]] || { usage; exit 1; }

pdfsets_dotversion=5.9.1
pdfsets_version=v${pdfsets_dotversion//./_}

cat <<EOF
Obtaining PDF sets ${pdfsets_version} from oink.fnal.gov.
If you want the latest, pull with lhapdf-getdata from lhapdf,
but be aware that this takes a very long time (likely most of the day).
EOF

cd "${1}" || { echo "ERROR: Unable to change directory to \"${1}\"." 1>&2; exit 1; }

pdfsets=pdfsets-${pdfsets_dotversion}-noarch.tar.bz2

if [[ -d "pdfsets/${pdfsets_version}" ]]; then
  echo "INFO: pdfsets ${pdfsets_version} already exists (-f to override)."
  exit 0
fi

if [[ -f "${pdfsets}" ]] && (( ${force:-0} == 0 )); then
  echo "INFO: ${pdfsets} already exists (-f to override)."
else
 curl --location -O --insecure --fail --silent \
 http://oink.fnal.gov/distro/packages/pdfsets/${pdfsets} || \
 { echo "ERROR: Unable to obtain latest PDF sets from oink.fnal.gov." 1>&2; exit 1; }
fi

tar xf "${pdfsets}" || \
 { echo "ERROR: Unable to untar ${pdfsets}: incomplete download? Remove and retry." 1>&2; exit 1; }

exit $?
